@@ -25,10 +25,11 @@ class GELFHandler(DatagramHandler):
     """
 
     def __init__(self, host, port=12201, chunk_size=WAN_CHUNK,
-            debugging_fields=True, extra_fields=True):
+            debugging_fields=True, extra_fields=True, fqdn=False):
         self.debugging_fields = debugging_fields
         self.extra_fields = extra_fields
         self.chunk_size = chunk_size
+        self.fqdn = fqdn
         DatagramHandler.__init__(self, host, port)
 
     def send(self, s):
@@ -40,7 +41,7 @@ class GELFHandler(DatagramHandler):
 
     def makePickle(self, record):
         message_dict = make_message_dict(
-            record, self.debugging_fields, self.extra_fields)
+            record, self.debugging_fields, self.extra_fields, self.fqdn)
         return zlib.compress(json.dumps(message_dict))
 
 
@@ -52,7 +53,7 @@ class ChunkedGELF(object):
         self.id = struct.pack('Q', random.randint(0, 0xFFFFFFFFFFFFFFFF))
 
     def message_chunks(self):
-        return (self.message[i:i+self.size] for i
+        return (self.message[i:i + self.size] for i
                     in range(0, len(self.message), self.size))
 
     def encode(self, sequence, chunk):
@@ -69,9 +70,13 @@ class ChunkedGELF(object):
             yield self.encode(sequence, chunk)
 
 
-def make_message_dict(record, debugging_fields, extra_fields):
+def make_message_dict(record, debugging_fields, extra_fields, fqdn):
+    if fqdn:
+        host = socket.getfqdn()
+    else:
+        host = socket.gethostname()
     fields = {'version': "1.0",
-        'host': socket.gethostname(),
+        'host': host,
         'short_message': record.getMessage(),
         'full_message': get_full_message(record.exc_info),
         'timestamp': record.created,
@@ -102,9 +107,11 @@ SYSLOG_LEVELS = {
     logging.DEBUG: 7,
 }
 
+
 def get_full_message(exc_info):
     return traceback.format_exc(exc_info) if exc_info else ''
 
+
 def add_extra_fields(message_dict, record):
     # skip_list is used to filter additional fields in a log message.
     # It contains all attributes listed in
